<?php
/**
 * @file
 * Rules integration for the Commerce Event Ticket PDF module.
 */

/**
 * Implements hook_rules_action_info().
 */
function commerce_event_ticket_pdf_rules_action_info() {
  $defaults = array(
    'group' => t('Commerce Event Ticket'),
    'module' => 'commerce_event_ticket_pdf',
    'access callback' => 'commerce_event_ticket_rules_config_access',
  );
  $actions = array();
  $actions['commerce_event_ticket_pdf_create_for_order'] = $defaults + array(
    'label' => t("Create a PDF for an order's tickets"),
    'parameter' => array(
      'order' => array(
        'type' => 'commerce_order',
        'label' => t('The order'),
      ),
    ),
  );
  return $actions;
}

/**
 * Implements hook_rules_event_info().
 */
function commerce_event_ticket_pdf_rules_event_info() {
  $defaults = array(
    'group' => t('Commerce Event Ticket'),
    'module' => 'commerce_event_ticket_pdf',
    'access callback' => 'commerce_event_ticket_rules_config_access',
  );
  $events = array();
  $events['commerce_event_ticket_pdf_created'] = $defaults + array(
    'label' => t('After a PDF ticket file has been created for an order'),
    'variables' => array(
      'file' => array(
        'type' => 'file',
        'label' => t('The PDF file containing the tickets for the order.'),
        'skip save' => TRUE,
      ),
      'order' => array(
        'type' => 'commerce_order',
        'label' => t('The Commerce order'),
        'skip save' => TRUE,
      ),
    ),
  );
  return $events;
}

/**
 * Rules action: create a PDF file for an order's tickets.
 */
function commerce_event_ticket_pdf_create_for_order($order) {
  $tickets = commerce_event_ticket_create_from_order($order);
  if (!$tickets) {
    return;
  }
  $file = commerce_event_ticket_pdf_create($order, 'commerce_order', $tickets);
  // Invoke the Rules event "After a PDF ticket file has been created for an
  // order".
  if ($file && isset($file->ticket_pdf_is_new)) {
    if (module_exists('rules')) {
      rules_invoke_all('commerce_event_ticket_pdf_created', $file, $order);
    }
    else {
      module_invoke_all('commerce_event_ticket_pdf_created', $file, $order);
    }
    unset($file->ticket_pdf_is_new);
  }
}
